Baseband: a Package for Radio Baseband I/O
==========================================

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1214268.svg
   :target: https://doi.org/10.5281/zenodo.1214268
   :alt: DOI 10.5281/zenodo.1214268

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy

.. image:: https://travis-ci.org/mhvk/baseband.svg?branch=master
   :target: https://travis-ci.org/mhvk/baseband
   :alt: Test Status

.. image:: https://codecov.io/gh/mhvk/baseband/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/mhvk/baseband
   :alt: Coverage Level

.. image:: https://readthedocs.org/projects/baseband/badge/?version=latest
   :target: https://baseband.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Baseband is a package for reading and writing VLBI and other radio baseband
files, with the aim of simplifying and streamlining data conversion and
standardization.  It relies on `NumPy <http://www.numpy.org/>`_ and `Astropy
<http://www.astropy.org/>`_.

For installation and usage instructions, please see the `online documentation
<https://baseband.readthedocs.io/>`_.

If you used this package in your research, please cite it via DOI
`10.5281/zenodo.1214268 <https://doi.org/10.5281/zenodo.1214268>`_.

Contributing
------------

Please open a new issue for bugs, feedback or feature requests.

We welcome code contributions, in particular support for new file formats!
To add a contribution, please submit a pull request.  If you would like
assistance in using GitHub or how to begin modifying Baseband, please feel free
to contact `@mhvk`_.

For more information on how to make code contributions, please see the `Astropy
developer documentation <http://docs.astropy.org/en/stable/index.html#developer-documentation)>`_.

License
-------

Baseband is licensed under the GNU General Public License v3.0 - see the
``LICENSE`` file.

.. _@mhvk: https://github.com/mhvk
